/*
 * Copyright 2011-2014 Univention GmbH
 *
 * http://www.univention.de/
 *
 * All rights reserved.
 *
 * The source code of this program is made available
 * under the terms of the GNU Affero General Public License version 3
 * (GNU AGPL V3) as published by the Free Software Foundation.
 *
 * Binary versions of this program provided by Univention to you as
 * well as other copyrighted, protected or trademarked materials like
 * Logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and Univention and not subject to the GNU AGPL V3.
 *
 * In the case you use this program under the terms of the GNU AGPL V3,
 * the program is provided in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public
 * License with the Debian GNU/Linux or Univention distribution in file
 * /usr/share/common-licenses/AGPL-3; if not, see
 * <http://www.gnu.org/licenses/>.
 */
/*global define*/

define([
    "dojo/_base/declare",
    "dojo/_base/lang",
    "umc/dialog",
    "ckeditor/ckeditor",
    "dojo-ckeditor/Editor",
    "umc/widgets/Form",
    "umc/widgets/ContainerWidget",
    "umc/widgets/CheckBox",
    "umc/widgets/TextBox",
    "umc/widgets/TextArea",
    "umc/widgets/StandbyMixin",
    "umc/widgets/Uploader",
    "umc/i18n!umc/modules/maildisclaimer"
], function(declare, lang, dialog, ckeditor, Editor, Form, ContainerWidget, CheckBox, TextBox, TextArea, StandbyMixin, Uploader, _) {
    return declare("umc.modules.maildisclaimer.DetailPage", [ ContainerWidget, StandbyMixin ], {
        // summary:
        //      This class represents the detail view of our dummy module.

        // reference to the modules store object
        moduleStore: null,

        // internal reference to the formular containing all form widgets of an UDM object
        _form: null,

        // Set the opacity for the standby animation to 100% in order to mask
        // GUI changes when the module is opened. Call this.standby(true|false)
        // to enabled/disable the animation.
        standbyOpacity: 1,

        postMixInProperties: function() {
            // is called after all inherited properties/methods have been mixed
            // into the object (originates from dijit._Widget)

            // it is important to call the parents postMixInProperties() method
            this.inherited(arguments);

            // configure buttons for the header of the detail page
            this.headerButtons = [{
                name: 'submit',
                label: _('Save'),
                iconClass: 'umcSaveIconWhite',
                callback: lang.hitch(this, function() {
                    this._save(this._form.get('value'));
                })
            }, {
                name: 'close',
                iconClass: 'umcCloseIconWhite',
                label: _('Back to overview'),
                callback: lang.hitch(this, 'onClose')
            }];
        },

        buildRendering: function() {
            // is called after all DOM nodes have been setup
            // (originates from dijit._Widget)

            // it is important to call the parents postMixInProperties() method
            this.inherited(arguments);

            this.renderDetailPage();
        },

        /*
        postCreate: function() {
            CKEDITOR.replace("content_html");
        },
        */

        renderDetailPage: function() {
            var tools = require('umc/tools');
            var version = tools.status()['version/version'];

            if (version === undefined) {
                version = "4.1";
            }

            version = version.split('.');

            var commandpath = '/univention-management-console/command/maildisclaimer';

            if (parseInt(version[0]) >= 4 && parseInt(version[1]) >= 2) {
                commandpath = '/univention/command/maildisclaimer';
            }

            // render the form containing all detail information that may be edited

            var editor_settings = {};

            editor_settings.enterMode = CKEDITOR.ENTER_BR;
            editor_settings.shiftEnterMode = CKEDITOR.ENTER_P;
            editor_settings.toolbar = 'MailDisclaimers';
            editor_settings.toolbar_MailDisclaimers = [
                ['Source'],
                ['Undo', 'Redo', '-', 'Find', 'Replace', 'SelectAll',
                'RemoveFormat'],
                ['Cut', 'Copy', 'Paste', 'PasteText', 'PasteFromWord'],
                ['NumberedList', 'BulletedList', '-', 'Outdent', 'Indent',
                'Blockquote'],
                ['Link', 'Unlink', 'Image', 'Table', 'HorizontalRule',
                'SpecialChar'],
                '/',
                ['Bold', 'Italic', 'Underline', 'Strike', '-', 'Subscript',
                'Superscript'],
                ['Format', 'Font', 'FontSize', 'TextColor', 'BGColor'],
                ['Maximize']
            ];
            editor_settings.font_names = 'Arial/Arial, Helvetica, sans-serif;' +
                'Times New Roman/Times New Roman, Times, serif;' +
                'Verdana/Verdana, sans-serif;' +
                'Courier New/Courier New, monospace;';
            editor_settings.fontSize_sizes = '8/8px;9/9px;10/10px;' +
                '11/11px;12/12px;' +
                '14/14px;16/16px;18/18px;20/20px;22/22px;24/24px;26/26px;' +
                '28/28px;36/36px;48/48px;72/72px';
            editor_settings.fullPage = true;
            editor_settings.toolbarCanCollapse = false;
            editor_settings.removePlugins = 'elementspath';
            editor_settings.removeButtons = ''; // otherwise Strikethrough and others disappear
            editor_settings.resize_enabled = true;
            editor_settings.resize_dir = 'both';
            editor_settings.filebrowserImageBrowseUrl = commandpath + '/getimage';
            editor_settings.filebrowserImageUploadUrl = commandpath + '/uploadimage';

            // specify all widgets
            var widgets = [{
                type: TextBox,
                name: 'id',
                disabled: true
            }, {
                type: CheckBox,
                name: 'global',
                label: _('Set as global'),
                description: _('Set this template as global and override this setting for other templates')
            }, {
                type: TextBox,
                name: 'name'
            }, {
                type: TextArea,
                name: 'content_txt'
            }, {
                type: Editor,
                name: 'content_html',
                settings: editor_settings
            }];

            // specify the layout... additional dicts are used to group form elements
            // together into title panes
            var layout = [{
                label: _('General'),
                layout: [ ['name', 'global'] ]
            }, {
                label: _('Plain Text'),
                layout: [ 'content_txt' ]
            }, {
                label: _('HTML'),
                layout: [ 'content_html' ]
            }];

            // create the form
            this._form = new Form({
                widgets: widgets,
                layout: layout,
                moduleStore: this.moduleStore
            });

            // add form to page...
            this.addChild(this._form);

            // hook to onSubmit event of the form
            this._form.on('submit', lang.hitch(this, '_save'));
        },

        _save: function(values) {
            this.standbyDuring( umc.tools.umcpCommand('maildisclaimer/add', values) ).then(lang.hitch(this, function() {
                this.onClose();
            }));
        },

        load: function(id) {
            // during loading show the standby animation
            this.standby(true);

            // load the object into the form... the load method returns a
            // Deferred object in order to handel asynchronity
            this._form.load(id).then(lang.hitch(this, function() {
                // done, switch of the standby animation
                this.standby(false);
            }), lang.hitch(this, function() {
                // error handler: switch of the standby animation
                // error messages will be displayed automatically
                this.standby(false);
            }));
        },

        clear: function() {
            this._form.clearFormValues();
        },

        onClose: function() {
            // event stub
            return true;
        }
    });
});
