/*
 * Copyright 2011-2014 Univention GmbH
 *
 * http://www.univention.de/
 *
 * All rights reserved.
 *
 * The source code of this program is made available
 * under the terms of the GNU Affero General Public License version 3
 * (GNU AGPL V3) as published by the Free Software Foundation.
 *
 * Binary versions of this program provided by Univention to you as
 * well as other copyrighted, protected or trademarked materials like
 * Logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and Univention and not subject to the GNU AGPL V3.
 *
 * In the case you use this program under the terms of the GNU AGPL V3,
 * the program is provided in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public
 * License with the Debian GNU/Linux or Univention distribution in file
 * /usr/share/common-licenses/AGPL-3; if not, see
 * <http://www.gnu.org/licenses/>.
 */
/*global define*/

define([
    "dojo/_base/declare",
    "dojo/_base/lang",
    "umc/dialog",
    "ckeditor/ckeditor",
    "dojo-ckeditor/Editor",
    "umc/widgets/Form",
    "umc/widgets/ContainerWidget",
    "umc/widgets/CheckBox",
    "umc/widgets/TextBox",
    "umc/widgets/Text",
    "umc/widgets/ComboBox",
    "umc/widgets/StandbyMixin",
    "umc/widgets/Uploader",
    "umc/i18n!umc/modules/maildisclaimer"
], function(declare, lang, dialog, ckeditor, Editor, Form, ContainerWidget, CheckBox, TextBox, Text, ComboBox, StandbyMixin, Uploader, _) {
    return declare("umc.modules.maildisclaimer.LicensePage", [ ContainerWidget, StandbyMixin ], {
        // summary:
        //      This class represents the detail view of our dummy module.

        // internal reference to the formular containing all form widgets of an UDM object
        _form: null,

        // Set the opacity for the standby animation to 100% in order to mask
        // GUI changes when the module is opened. Call this.standby(true|false)
        // to enabled/disable the animation.
        standbyOpacity: 1.0,

        changedValues: [],

        postMixInProperties: function() {
            // is called after all inherited properties/methods have been mixed
            // into the object (originates from dijit._Widget)

            // it is important to call the parents postMixInProperties() method
            this.inherited(arguments);

            // configure buttons for the header of the detail page
            this.headerButtons = [{
                name: 'submit',
                label: _('Save'),
                iconClass: 'umcSaveIconWhite',
                callback: lang.hitch(this, function() {
                    this._save(this._form.get('value'));
                })
            }, {
                name: 'close',
                iconClass: 'umcCloseIconWhite',
                label: _('Back to overview'),
                callback: lang.hitch(this, 'confirmClose')
            }];
        },

        buildRendering: function() {
            // is called after all DOM nodes have been setup
            // (originates from dijit._Widget)

            // it is important to call the parents postMixInProperties() method
            this.inherited(arguments);

            this.renderLicensePage();
        },

        renderLicensePage: function() {
            var widgets = [{
                type: Text,
                name: 'license'
            }, {
                type: Uploader,
                name: 'upload'
            }];

            var layout = [{
                label: _('Overview'),
                layout: [ ['license'] ]
            }, {
                label: _('New license'),
                layout: [ 'upload' ]
            }];

            this._form = new Form({
                widgets: widgets,
                layout: layout
            });

            // add form to page...
            this.addChild(this._form);

            // hook to onSubmit event of the form
            this._form.on('submit', lang.hitch(this, '_save'));

            this._form.getWidget("upload").on("change", lang.hitch(this, function(value) {
                if (value) {
                    this.changedValues.push("upload");
                }
                else {
                    this.changedValues = [];
                }
            }));
        },

        _save: function(values) {
            if (values["upload"]) {
                this.standbyDuring( umc.tools.umcpCommand('maildisclaimer/add_license', values) ).then(lang.hitch(this, function() {
                    this.load();
                    this.clear();
                }));
            }
        },

        load: function(id) {
            umc.tools.umcpCommand('maildisclaimer/get_license').then(lang.hitch(this, function(msg) {
                this.clear();
                this._form.getWidget("license").set("content", "<pre>" + msg.result + "</pre>");
            }));

        },

        clear: function() {
            this._form.clearFormValues();
            this.changedValues = [];
        },

        confirmClose: function() {
            if (this.changedValues.length) {
                return dialog.confirm(_('There are unsaved changes. Are you sure to cancel?'), [{
                    label: _('Continue editing'),
                    name: 'cancel'
                }, {
                    label: _('Discard changes'),
                    name: 'quit',
                    'default': true,
                    callback: lang.hitch(this, 'onClose')
                }]);
            }
            else {
                this.onClose();
            }
        },

        onClose: function() {
            // event stub
            return true;
        }
    });
});
